@@ -12,7 +12,6 @@
 #include <assert.h>
 
 #include "../fio.h"
-#include "../os.h"
 
 struct null_data {
 	struct io_u **io_us;
@@ -66,21 +65,9 @@ static int fio_null_queue(struct thread_data fio_unused *td, struct io_u *io_u)
 	return FIO_Q_QUEUED;
 }
 
-static int fio_null_setup(struct thread_data *td)
-{
-	struct fio_file *f;
-	unsigned int i;
-
-	for_each_file(td, f, i)
-		f->real_file_size = -1ULL;
-
-	return 0;
-}
-
 static int fio_null_open(struct thread_data fio_unused *td,
 			 struct fio_file fio_unused *f)
 {
-	f->fd = 0;
 	return 0;
 }
 
@@ -115,7 +102,6 @@ static int fio_null_init(struct thread_data *td)
 static struct ioengine_ops ioengine = {
 	.name		= "null",
 	.version	= FIO_IOOPS_VERSION,
-	.setup		= fio_null_setup,
 	.queue		= fio_null_queue,
 	.commit		= fio_null_commit,
 	.getevents	= fio_null_getevents,
