@@ -35,6 +35,7 @@
 #include <sys/mman.h>
 
 #include "fio.h"
+#include "hash.h"
 
 unsigned long page_mask;
 unsigned long page_size;
@@ -310,6 +311,7 @@ static void do_verify(struct thread_data *td)
 
 		if (runtime_exceeded(td, &io_u->start_time)) {
 			put_io_u(td, io_u);
+			td->terminate = 1;
 			break;
 		}
 
@@ -332,6 +334,7 @@ static void do_verify(struct thread_data *td)
 				ret = -io_u->error;
 			else if (io_u->resid) {
 				int bytes = io_u->xfer_buflen - io_u->resid;
+				struct fio_file *f = io_u->file;
 
 				/*
 				 * zero read, fail
@@ -345,8 +348,11 @@ static void do_verify(struct thread_data *td)
 				io_u->xfer_buflen = io_u->resid;
 				io_u->xfer_buf += bytes;
 				io_u->offset += bytes;
+				f->last_completed_pos = io_u->offset;
 
-				if (io_u->offset == io_u->file->real_file_size)
+				td->ts.short_io_u[io_u->ddir]++;
+
+				if (io_u->offset == f->real_file_size)
 					goto sync_done;
 
 				requeue_io_u(td, &io_u);
@@ -436,6 +442,7 @@ static void do_io(struct thread_data *td)
 
 		if (runtime_exceeded(td, &s)) {
 			put_io_u(td, io_u);
+			td->terminate = 1;
 			break;
 		}
 
@@ -446,6 +453,7 @@ static void do_io(struct thread_data *td)
 				ret = -io_u->error;
 			else if (io_u->resid) {
 				int bytes = io_u->xfer_buflen - io_u->resid;
+				struct fio_file *f = io_u->file;
 
 				/*
 				 * zero read, fail
@@ -459,8 +467,11 @@ static void do_io(struct thread_data *td)
 				io_u->xfer_buflen = io_u->resid;
 				io_u->xfer_buf += bytes;
 				io_u->offset += bytes;
+				f->last_completed_pos = io_u->offset;
 
-				if (io_u->offset == io_u->file->real_file_size)
+				td->ts.short_io_u[io_u->ddir]++;
+
+				if (io_u->offset == f->real_file_size)
 					goto sync_done;
 
 				requeue_io_u(td, &io_u);
@@ -588,14 +599,17 @@ static void cleanup_io_u(struct thread_data *td)
 /*
  * "randomly" fill the buffer contents
  */
-static void fill_rand_buf(struct io_u *io_u, int max_bs)
+static void fill_io_buf(struct thread_data *td, struct io_u *io_u, int max_bs)
 {
-	int *ptr = io_u->buf;
+	long *ptr = io_u->buf;
 
-	while ((void *) ptr - io_u->buf < max_bs) {
-		*ptr = rand() * 0x9e370001;
-		ptr++;
-	}
+	if (!td->o.zero_buffers) {
+		while ((void *) ptr - io_u->buf < max_bs) {
+			*ptr = rand() * GOLDEN_RATIO_PRIME;
+			ptr++;
+		}
+	} else
+		memset(ptr, 0, max_bs);
 }
 
 static int init_io_u(struct thread_data *td)
@@ -636,8 +650,9 @@ static int init_io_u(struct thread_data *td)
 		INIT_LIST_HEAD(&io_u->list);
 
 		io_u->buf = p + max_bs * i;
-		if (td_write(td) || td_rw(td))
-			fill_rand_buf(io_u, max_bs);
+
+		if (td_write(td))
+			fill_io_buf(td, io_u, max_bs);
 
 		io_u->index = i;
 		io_u->flags = IO_U_F_FREE;
@@ -662,7 +677,11 @@ static int switch_ioscheduler(struct thread_data *td)
 
 	f = fopen(tmp, "r+");
 	if (!f) {
-		td_verror(td, errno, "fopen");
+		if (errno == ENOENT) {
+			log_err("fio: os or kernel doesn't support IO scheduler switching\n");
+			return 0;
+		}
+		td_verror(td, errno, "fopen iosched");
 		return 1;
 	}
 
@@ -810,7 +829,7 @@ static void *thread_main(void *data)
 
 	runtime[0] = runtime[1] = 0;
 	clear_state = 0;
-	while (td->o.loops--) {
+	while (td->o.time_based || td->o.loops--) {
 		fio_gettime(&td->start, NULL);
 		memcpy(&td->ts.stat_sample_time, &td->start, sizeof(td->start));
 
