@@ -135,6 +135,7 @@ struct io_u {
 	void *buf;
 	unsigned long buflen;
 	unsigned long long offset;
+	unsigned long long endpos;
 
 	/*
 	 * IO engine state, may be different from above when we get
@@ -224,6 +225,7 @@ enum fio_filetype {
 	FIO_TYPE_FILE = 1,		/* plain file */
 	FIO_TYPE_BD,			/* block device */
 	FIO_TYPE_CHAR,			/* character device */
+	FIO_TYPE_PIPE,			/* pipe */
 };
 
 enum fio_ioengine_flags {
@@ -236,13 +238,12 @@ enum fio_ioengine_flags {
 
 enum fio_file_flags {
 	FIO_FILE_OPEN		= 1 << 0,	/* file is open */
-	FIO_FILE_UNLINK		= 1 << 1,	/* unlink on close */
-	FIO_FILE_CLOSING	= 1 << 2,	/* file being closed */
-	FIO_FILE_EXISTS		= 1 << 3,	/* file there */
-	FIO_FILE_EXTEND		= 1 << 4,	/* needs extend */
-	FIO_FILE_NOSORT		= 1 << 5,	/* don't sort verify blocks */
-	FIO_FILE_DONE		= 1 << 6,	/* io completed to this file */
-	FIO_SIZE_KNOWN		= 1 << 7,	/* size has been set */
+	FIO_FILE_CLOSING	= 1 << 1,	/* file being closed */
+	FIO_FILE_EXISTS		= 1 << 2,	/* file there */
+	FIO_FILE_EXTEND		= 1 << 3,	/* needs extend */
+	FIO_FILE_NOSORT		= 1 << 4,	/* don't sort verify blocks */
+	FIO_FILE_DONE		= 1 << 5,	/* io completed to this file */
+	FIO_SIZE_KNOWN		= 1 << 6,	/* size has been set */
 };
 
 /*
@@ -331,6 +332,7 @@ struct thread_stat {
 	unsigned int io_u_map[FIO_IO_U_MAP_NR];
 	unsigned int io_u_lat[FIO_IO_U_LAT_NR];
 	unsigned long total_io_u[2];
+	unsigned long short_io_u[2];
 
 	unsigned long long io_bytes[2];
 	unsigned long runtime[2];
@@ -409,6 +411,8 @@ struct thread_options {
 	unsigned int file_service_type;
 	unsigned int group_reporting;
 	unsigned int fadvise_hint;
+	unsigned int zero_buffers;
+	unsigned int time_based;
 
 	char *read_iolog_file;
 	char *write_iolog_file;
