@@ -17,7 +17,7 @@
 #include "fio.h"
 #include "parse.h"
 
-static char fio_version_string[] = "fio 1.15.2";
+static char fio_version_string[] = "fio 1.16";
 
 #define FIO_RANDSEED		(0xb1899bedUL)
 
@@ -274,6 +274,11 @@ static int fixup_options(struct thread_data *td)
 		return 1;
 	}
 
+	if (!o->timeout && o->time_based) {
+		log_err("fio: time_based requires a runtime/timeout setting\n");
+		o->time_based = 0;
+	}
+
 	return 0;
 }
 
@@ -550,6 +555,7 @@ static int parse_jobs_ini(char *file, int stonewall_flag)
 	FILE *f;
 	char *p;
 	int ret = 0, stonewall;
+	int first_sect = 1;
 
 	f = fopen(file, "r");
 	if (!f) {
@@ -582,9 +588,11 @@ static int parse_jobs_ini(char *file, int stonewall_flag)
 		name[strlen(name) - 1] = '\0';
 
 		if (dump_cmdline) {
-			log_info("fio ");
+			if (first_sect)
+				log_info("fio ");
 			if (!global)
 				log_info("--name=%s ", name);
+			first_sect = 0;
 		}
 
 		td = get_new_job(global, &def_thread);
@@ -782,7 +790,11 @@ static int parse_cmd_line(int argc, char *argv[])
 				td = NULL;
 			}
 			if (!td) {
-				int global = !strncmp(val, "global", 6);
+				int global = 0;
+
+				if (strncmp(opt, "name", 4) ||
+				    !strncmp(val, "global", 6))
+					global = 1;
 
 				td = get_new_job(global, &def_thread);
 				if (!td)
