@@ -64,6 +64,13 @@ static int str_lockmem_cb(void fio_unused *data, unsigned long *val)
 static int str_prioclass_cb(void *data, unsigned int *val)
 {
 	struct thread_data *td = data;
+	unsigned short mask;
+
+	/*
+	 * mask off old class bits, str_prio_cb() may have set a default class
+	 */
+	mask = (1 << IOPRIO_CLASS_SHIFT) - 1;
+	td->ioprio &= mask;
 
 	td->ioprio |= *val << IOPRIO_CLASS_SHIFT;
 	return 0;
@@ -74,6 +81,13 @@ static int str_prio_cb(void *data, unsigned int *val)
 	struct thread_data *td = data;
 
 	td->ioprio |= *val;
+
+	/*
+	 * If no class is set, assume BE
+	 */
+	if ((td->ioprio >> IOPRIO_CLASS_SHIFT) == 0)
+		td->ioprio |= IOPRIO_CLASS_BE << IOPRIO_CLASS_SHIFT;
+
 	return 0;
 }
 #endif
@@ -477,6 +491,12 @@ static struct fio_option options[] = {
 		.help	= "Stop workload when this amount of time has passed",
 		.def	= "0",
 	},
+	{
+		.name	= "time_based",
+		.type	= FIO_OPT_STR_SET,
+		.off1	= td_var_offset(time_based),
+		.help	= "Keep running until runtime/timeout is met",
+	},
 	{
 		.name	= "mem",
 		.alias	= "iomem",
@@ -826,6 +846,12 @@ static struct fio_option options[] = {
 		.off1	= td_var_offset(group_reporting),
 		.help	= "Do reporting on a per-group basis",
 	},
+	{
+		.name	= "zero_buffers",
+		.type	= FIO_OPT_STR_SET,
+		.off1	= td_var_offset(zero_buffers),
+		.help	= "Init IO buffers to all zeroes",
+	},
 	{
 		.name = NULL,
 	},
